"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isRunningInVehicleServices = exports.androidNativeHelpers = void 0;
const triggerAndroid_1 = require("../util/triggerAndroid");
const isRunningInVehicleServices = (() => {
    try {
        //@ts-ignore
        const android = Android;
        return (android !== undefined);
    }
    catch {
        return false;
    }
})();
exports.isRunningInVehicleServices = isRunningInVehicleServices;
/**
 *
 * This is a helper method which triggers the 'triggerAndroid' method.
 * This method allows you to pass serializable data to the arguments whereas triggerAndroid only accepts primitives.
 * @ignore
 * @param insideVs boolean for if you are in VehicleServices or not
 */
const androidNativeHelpers = (insideVs) => ({
    sendNotification: (notification) => {
        if (insideVs) {
            try {
                const arg = JSON.stringify(notification);
                (0, triggerAndroid_1.triggerAndroid)("sendNotification", arg);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    apiReady: () => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("apiReady");
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setItem: (key, value) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("setItem", key, value);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    getItem: (key) => {
        if (insideVs) {
            try {
                return (0, triggerAndroid_1.triggerAndroid)("getItem", key);
            }
            catch (e) {
                console.error(e);
            }
        }
        return null;
    },
    deleteItem: (key) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("deleteItem", key);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    clearItems: () => {
        if (insideVs) {
            try {
                console.log('this called');
                (0, triggerAndroid_1.triggerAndroid)("clearItems");
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setHospital: (id) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("setHospital", id);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setPriority: (id) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("setPriority", id);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setNavLayerPoint: (id, layerData) => {
        if (insideVs) {
            try {
                const arg = JSON.stringify(layerData);
                (0, triggerAndroid_1.triggerAndroid)("setNavLayerPoint", id, arg);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    setNavLayerShape: (id, layerData) => {
        if (insideVs) {
            try {
                const arg = JSON.stringify(layerData);
                (0, triggerAndroid_1.triggerAndroid)("setNavLayerShape", id, arg);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    deleteNavLayer: (id) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("deleteNavLayer", id);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    sendRawRakelAction: (rawRakelAction) => {
        if (insideVs) {
            try {
                const data = JSON.stringify(rawRakelAction);
                (0, triggerAndroid_1.triggerAndroid)("sendRawRakelAction", data);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    putAppInForeground: () => {
        if (insideVs) {
            (0, triggerAndroid_1.triggerAndroid)("putAppInForeground");
        }
    },
    removeNotification: (notificationId) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("removeNotification", notificationId);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    makeCall: (number) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("makeCall", number);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    answerCall: (callId) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("answerCall", callId);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    hangUpCall: (callId) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("hangUpCall", callId);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    holdCall: (callId) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("holdCall", callId);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    unholdCall: (callId) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("unholdCall", callId);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    muteMicrophone: () => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("muteMicrophone");
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    unmuteMicrophone: () => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("unmuteMicrophone");
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    selectAudioDeviceType: (audioDeviceType) => {
        if (insideVs) {
            try {
                const data = JSON.stringify(audioDeviceType);
                (0, triggerAndroid_1.triggerAndroid)("selectAudioDeviceType", data);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    playRingtone: (filePath) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("playRingtone", filePath);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    stopRingtone: (filePath) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("stopRingtone", filePath);
            }
            catch (e) {
                console.error(e);
            }
        }
    },
    enableIntercom: (enable) => {
        if (insideVs) {
            try {
                (0, triggerAndroid_1.triggerAndroid)("enableIntercom", enable);
            }
            catch (e) {
                console.error(e);
            }
        }
    }
});
exports.androidNativeHelpers = androidNativeHelpers;
//# sourceMappingURL=AndroidNativeHelpers.js.map