"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.imagePaintStyle = exports.generateGeoJsonPointsLayerFromFeatures = exports.generateShapeNavLayerGeoJsonFeatures = exports.generatePointsNavLayerGeoJsonFeatures = exports.generateFillLayer = exports.generateTextLayer = exports.generateImageLayer = exports.generateImageLayout = void 0;
const generateImageLayout = (imageId) => ({
    "text-field": ["get", "feature-text"],
    "text-allow-overlap": false,
    "text-ignore-placement": false,
    "text-anchor": "top",
    "icon-anchor": "bottom",
    "icon-image": imageId,
    "text-size": 14
});
exports.generateImageLayout = generateImageLayout;
const imagePaintStyle = {
    "text-color": "#000",
    "text-halo-color": "#fff",
    "text-halo-width": 1,
    "text-halo-blur": 0
};
exports.imagePaintStyle = imagePaintStyle;
const generateImageLayer = (layerId, sourceId, imageId) => ({
    id: layerId,
    "type": "symbol",
    "source": sourceId,
    "layout": generateImageLayout(imageId),
    "paint": imagePaintStyle
});
exports.generateImageLayer = generateImageLayer;
const generateTextLayer = (labelId, sourceId) => ({
    id: labelId,
    type: "symbol",
    source: sourceId,
    layout: {
        "text-field": ["get", "feature-text"],
        "text-size": 12,
        "text-anchor": "center",
        "text-justify": "center",
        "text-offset": [0, 0.5] // Adjust the offset to position the text above the shape
    },
    paint: {
        "text-color": "#000000"
    }
});
exports.generateTextLayer = generateTextLayer;
const generateFillLayer = (layerId, sourceId) => ({
    id: layerId,
    "type": "fill",
    "source": sourceId,
    "paint": {
        "fill-color": ["get", "fill-color"],
        "fill-opacity": 0.8,
    },
});
exports.generateFillLayer = generateFillLayer;
const generatePointsNavLayerGeoJsonFeatures = (layerDataArray) => layerDataArray.map(({ point: { longitude, latitude }, icon, text }) => {
    return {
        type: "Feature",
        "geometry": {
            "type": "Point",
            "coordinates": [longitude, latitude]
        },
        properties: {
            "feature-text": text
        }
    };
});
exports.generatePointsNavLayerGeoJsonFeatures = generatePointsNavLayerGeoJsonFeatures;
const generateShapeNavLayerGeoJsonFeatures = (layerDataArray) => layerDataArray.map(({ text, points, color }) => {
    const coordinates = [points.map(({ longitude, latitude }) => [
            longitude,
            latitude
        ])];
    return {
        type: "Feature",
        properties: {
            "fill-color": color,
            "feature-text": text
        },
        geometry: {
            coordinates,
            type: "Polygon"
        }
    };
});
exports.generateShapeNavLayerGeoJsonFeatures = generateShapeNavLayerGeoJsonFeatures;
const generateGeoJsonPointsLayerFromFeatures = (geoJsonFeatures) => ({
    type: "geojson",
    data: {
        "type": "FeatureCollection",
        "features": geoJsonFeatures,
    }
});
exports.generateGeoJsonPointsLayerFromFeatures = generateGeoJsonPointsLayerFromFeatures;
//# sourceMappingURL=layerLayout.js.map