"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_2 = require("@chakra-ui/react");
const framer_motion_1 = require("framer-motion");
const util_1 = require("../util");
const NotificationComponent = ({ notification, onTrigger, onRemove }) => {
    const [willDelete, setWillDelete] = (0, react_1.useState)(false);
    const constraintsRef = (0, react_1.useRef)(null);
    const PrimaryButton = (0, react_1.useMemo)(() => {
        return () => ((0, jsx_runtime_1.jsx)(react_2.Button, { color: "white", backgroundColor: "darkorange", borderRadius: "full", onClick: () => {
                if (notification.primaryButton.callback !== undefined)
                    onTrigger(notification.primaryButton.callback);
            }, children: notification.primaryButton.label }));
    }, [notification.primaryButton.callback, notification.primaryButton.label, onTrigger]);
    const SecondaryButton = (0, react_1.useMemo)(() => {
        return () => ((0, jsx_runtime_1.jsx)(react_2.Button, { color: "white", backgroundColor: "black", border: "2px solid white", boxSizing: "border-box", borderRadius: "full", onClick: () => {
                if (notification.secondaryButton.callback !== undefined)
                    onTrigger(notification.secondaryButton.callback);
            }, children: notification.secondaryButton.label }));
    }, [notification.secondaryButton, onTrigger]);
    const formattedTime = (0, react_1.useMemo)(() => {
        const hours = new Date().getHours().toString();
        const minutes = new Date().getMinutes().toString().padStart(2, "0");
        return `Evam Development Environment • ${hours}:${minutes}`;
    }, []);
    const handleDragStart = (0, react_1.useCallback)((e, info) => {
        if (typeof window !== "undefined") {
            const viewportWidth = window.innerWidth;
            const dropPositionX = info.point.x + info.offset.x;
            if (dropPositionX > viewportWidth / 2 + 200) {
                setWillDelete(true);
            }
            else if (willDelete) {
                setWillDelete(false);
            }
        }
    }, [willDelete]);
    const handleDragEnd = (0, react_1.useCallback)((e, info) => {
        if (typeof window !== "undefined") {
            const viewportWidth = window.innerWidth;
            const dropPositionX = info.point.x + info.offset.x;
            if (dropPositionX > ((viewportWidth / 2) + 500)) {
                onRemove(notification);
            }
            setWillDelete(false);
        }
    }, [notification, onRemove]);
    const dragMotionProps = {
        drag: "x",
        dragElastic: 1,
        onDrag: handleDragStart,
        onDragEnd: handleDragEnd,
        dragConstraints: constraintsRef,
    };
    return ((0, jsx_runtime_1.jsx)(util_1.VehicleServicesNoRender, { children: (0, jsx_runtime_1.jsx)(framer_motion_1.motion.div, { style: {
                zIndex: 9999,
            }, ref: constraintsRef, children: (0, jsx_runtime_1.jsx)(framer_motion_1.motion.div, { ...dragMotionProps, children: (0, jsx_runtime_1.jsxs)(react_2.Card, { _hover: {
                        cursor: "grab"
                    }, _active: {
                        cursor: "grabbing"
                    }, w: "500px", backgroundColor: "black", color: "white", zIndex: 9999, style: {
                        userSelect: "none",
                        opacity: willDelete ? 0.2 : 1,
                        filter: willDelete ? "blur(1px)" : "none",
                    }, children: [(0, jsx_runtime_1.jsx)(react_2.CardHeader, { children: (0, jsx_runtime_1.jsxs)(react_2.HStack, { children: [(0, jsx_runtime_1.jsx)(react_2.Icon, { fill: "gray", boxSize: 6, children: (0, jsx_runtime_1.jsx)("path", { d: "M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm1 15h-2v-6h2v6zm0-8h-2V7h2v2z" }) }), (0, jsx_runtime_1.jsx)(react_2.Heading, { size: "sm", color: "gray", fontWeight: "none", children: formattedTime })] }) }), (0, jsx_runtime_1.jsxs)(react_2.CardBody, { pt: 0, children: [(0, jsx_runtime_1.jsx)(react_2.Heading, { size: "sm", mb: 5, children: notification.heading }), (0, jsx_runtime_1.jsx)(react_2.Text, { children: notification.description })] }), (0, jsx_runtime_1.jsx)(react_2.CardFooter, { children: (0, jsx_runtime_1.jsxs)(react_2.HStack, { w: "full", justifyContent: "right", children: [(notification.secondaryButton !== undefined) ? (0, jsx_runtime_1.jsx)(SecondaryButton, {}) : null, (0, jsx_runtime_1.jsx)(PrimaryButton, {})] }) })] }) }) }) }));
};
exports.default = NotificationComponent;
//# sourceMappingURL=NotificationComponent.js.map