"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AudioDevices = void 0;
const AudioDevicesType_1 = require("./AudioDevicesType");
class AudioDevices {
    /**
     * Class representing the payload for event NewOrUpdatedAudioDeviceTypes.
     * @param availableTypes the available types of audio devices for phone calls
     * @param selectedType the selected audio device type for phone calls.
     */
    constructor(availableTypes, selectedType) {
        this.availableTypes = availableTypes;
        this.selectedType = selectedType;
    }
    static fromJSON(audioDevices) {
        const selectedType = AudioDevicesType_1.AudioDevicesType[audioDevices.selectedType];
        if (selectedType === undefined) {
            throw Error("Invalid audio device type in fromJSON for audio devices");
        }
        let availableTypes;
        const availableTypesList = audioDevices.availableTypes;
        if (Array.isArray(availableTypesList)) {
            availableTypes = availableTypesList.map((type) => {
                const audioType = AudioDevicesType_1.AudioDevicesType[type];
                if (audioType === null) {
                    throw Error("Invalid audio device type in fromJSON for audio devices");
                }
                return audioType;
            });
        }
        else {
            throw Error("Available audio devices types is not an array");
        }
        return new AudioDevices(availableTypes, selectedType);
    }
}
exports.AudioDevices = AudioDevices;
//# sourceMappingURL=AudioDevices.js.map