"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Battery = exports.BatteryStatus = exports.BatteryPlugged = exports.BatteryHealth = void 0;
var BatteryHealth;
(function (BatteryHealth) {
    BatteryHealth["UNKNOWN"] = "UNKNOWN";
    BatteryHealth["GOOD"] = "GOOD";
    BatteryHealth["OVERHEAT"] = "OVERHEAT";
    BatteryHealth["DEAD"] = "DEAD";
    BatteryHealth["OVER_VOLTAGE"] = "OVER_VOLTAGE";
    BatteryHealth["UNSPECIFIED_FAILURE"] = "UNSPECIFIED_FAILURE ";
    BatteryHealth["COLD"] = "COLD";
})(BatteryHealth || (BatteryHealth = {}));
exports.BatteryHealth = BatteryHealth;
var BatteryPlugged;
(function (BatteryPlugged) {
    BatteryPlugged["DOCK"] = "DOCK";
    BatteryPlugged["AC"] = "AC";
    BatteryPlugged["USB"] = "USB";
    BatteryPlugged["WIRELESS"] = "WIRELESS";
})(BatteryPlugged || (BatteryPlugged = {}));
exports.BatteryPlugged = BatteryPlugged;
var BatteryStatus;
(function (BatteryStatus) {
    BatteryStatus["UNKNOWN"] = "UNKNOWN";
    BatteryStatus["CHARGING"] = "CHARGING";
    BatteryStatus["DISCHARGING"] = "DISCHARGING";
    BatteryStatus["NOT_CHARGING"] = "NOT_CHARGING";
    BatteryStatus["FULL"] = "FULL";
})(BatteryStatus || (BatteryStatus = {}));
exports.BatteryStatus = BatteryStatus;
class Battery {
    /**
     *  Class representing the device's battery health, status and plugged state.
     *  See https://developer.android.com/reference/android/os/BatteryManager for more information.
     * @param health the battery's health (either UNKNOWN, GOOD, OVERHEAT, DEAD, OVER_VOLTAGE, UNSPECIFIED_FAILURE, COLD)
     * @param plugged the battery's plugged status (either DOCK, AC, USB, WIRELESS)
     * @param status the battery's status (either UNKNOWN, CHARGING, DISCHARGING, NOT_CHARGING, FULL)
     * @param capacity Remaining battery capacity as an integer percentage of total capacity (with no fractional part).
     */
    constructor(health, plugged, status, capacity) {
        this.health = health;
        this.plugged = plugged;
        this.status = status;
        this.capacity = capacity;
    }
    /**
     * Create from JSON
     * @param battery JSON object
     */
    static fromJSON(battery) {
        return new Battery(battery.health, battery.plugged, battery.status, battery.capacity);
    }
}
exports.Battery = Battery;
//# sourceMappingURL=Battery.js.map